@@ -1,6 +1,6 @@
 /*
  * XML LDAP client
- * $Id: xdap.c,v 1.12 2003/11/18 22:12:02 dsandras Exp $
+ * $Id: xdap.c,v 1.16 2004/02/09 20:10:09 dsandras Exp $
  * Copyright 2001 paul666@mailandnews.com
  * Licensed under version 2 or later of the GNU GPL
  */
@@ -11,6 +11,7 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "../../config.h"
 
 #include "xdap.h"
 
@@ -41,11 +42,13 @@ xdapfree(void)
 	int i;
 	for (i = 0; i < nregs; i++)
 		if (regs[i].refcount != 0) {
-			if ((regs[i].val == 0) || (regs[i].val == (void *)0xdeadbeef))
-				fprintf(stderr, "BOGUSFREE %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
+			if ((regs[i].val == 0) || (regs[i].val == (void *)0xdeadbeef)) {
+				////fprintf(stderr, "BOGUSFREE %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
+                                //
+                        }
 			else {
 #if DEBUGXDAPLEAK
-				fprintf(stderr, "FREE %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
+				//fprintf(stderr, "FREE %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
 #endif
 				free(regs[i].val);
 				regs[i].refcount = 0;
@@ -89,13 +92,11 @@ registerptr(void *ptr)
 		}
 		regs[i].refcount = 1;
 		regs[i].val = ptr;
-		if (i >= REGMAX - 3) /* overflow */
-			fprintf(stderr, "OVERFLOW %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
-		else
-			nregs++;
+		if (i < REGMAX - 3) 
+                  nregs++;
 	}
 #if DEBUGXDAPLEAK
-	fprintf(stderr, "RP %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
+	//fprintf(stderr, "RP %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
 #endif
 }
 
@@ -118,7 +119,7 @@ deregisterNode(xmlNodePtr node)
 	for (i = 0; i < nregs; i++)
 		if ((regs[i].refcount > 0) && (regs[i].val == node->_private)) {
 			regs[i].refcount--;
-			fprintf(stderr, "DN %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
+			//fprintf(stderr, "DN %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
 			if (regs[i].refcount == 0) {
 				free(regs[i].val);
 				regs[i].val = (void *)0xdeadbeef;
@@ -129,7 +130,7 @@ deregisterNode(xmlNodePtr node)
 		regs[i].refcount = -1;
 		regs[i].val = node->_private;
 #if DEBUGXDAPLEAK
-		fprintf(stderr, "DN %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
+	//fprintf(stderr, "DN %d %d %lx\n", i, regs[i].refcount, (unsigned long)regs[i].val);
 #endif
 	}
 }
@@ -156,7 +157,12 @@ parseonly (char *filename, xmlEntityPtr (*getent) (void *, const xmlChar *),
 	   xmlEntityPtr (**oldgetent) (void *, const xmlChar *), int noerr)
 {
   xmlDocPtr xp;
+
+#if HAVE_XMLSAXHANDLERV1
   xmlSAXHandlerV1 sax;
+#else
+  xmlSAXHandler sax;
+#endif
 
   memset (&sax, 0, sizeof sax);
   sax = xmlDefaultSAXHandler;	/* Copy original handler */
@@ -340,7 +346,7 @@ ldaprun (LDAP * ldap, xmlDocPtr xp, xmlNodePtr * current, int *opp,
   int optype;		/* ldap operation */
   xmlChar *base = 0;	/* search base */
   xmlChar *scope = 0;	/* search scope symbolic */
-  int iscope;		/* search scope */
+  int iscope = 0;	/* search scope */
   xmlChar *filter = 0;	/* search filter */
   xmlChar *attrlist = 0;	/* attribute list to return */
   char *attra[MAXATTRS];	/* attribute list in array form */
@@ -561,7 +567,7 @@ doldapop (LDAP * ldap, xmlDocPtr xp, int sync, xmlNodePtr node, int optype,
   LDAPMod *attrs[MAXATTRS];	/* attribute pointers */
   LDAPMessage *res;	/* result list from search */
   int nattrs = 0;		/* Number of attributes */
-  int rc;
+  int rc = 0;
   char *text = 0;		/* shell command */
   xmlChar *modop;		/* attribute mod_op */
   xmlChar *eval;		/* evaluate the element text */
