@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         callbacks.h  -  description
  *                         ---------------------------
  *   begin                : Sat Dec 23 2000
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : This file contains callbacks common to several
  *                          files.
  *
@@ -48,9 +48,8 @@
  * BEHAVIOR : Hold the current call.
  * PRE : /
  */
-void
-hold_call_cb (GtkWidget *,
-	      gpointer);
+void hold_call_cb (GtkWidget *,
+		   gpointer);
 
 
 /* DESCRIPTION : This callback is called when the user chooses to forward
@@ -58,17 +57,16 @@ hold_call_cb (GtkWidget *,
  * BEHAVIOR : Forward the current call.
  * PRE : /
  */
-void
-transfer_call_cb (GtkWidget *,
-		  gpointer);
+void transfer_call_cb (GtkWidget *,
+		       gpointer);
+
 
 /* DESCRIPTION  :  This callback is called when the user chooses to save.
  * BEHAVIOR     :  Saves the picture in the current video stream in a file.
  * PRE          :  /
  */
-void
-save_callback (GtkWidget *,
-	       gpointer);
+void save_callback (GtkWidget *,
+		    gpointer);
 
 
 /* DESCRIPTION  :  This callback is called when the user chooses to pause
@@ -76,9 +74,8 @@ save_callback (GtkWidget *,
  * BEHAVIOR     :  Pause the audio or video channel transmission.
  * PRE          :  gpointer = 0 (audio) or 1 (video)
  */
-void
-pause_channel_callback (GtkWidget *,
-			gpointer);
+void pause_channel_callback (GtkWidget *,
+			     gpointer);
 
 
 /* DESCRIPTION  :  This callback is called when the user chooses to open
@@ -86,9 +83,17 @@ pause_channel_callback (GtkWidget *,
  * BEHAVIOR     :  Open the about window.
  * PRE          :  /
  */
-void
-about_callback (GtkWidget *,
-		gpointer);
+void about_callback (GtkWidget *,
+		     gpointer);
+
+
+/* DESCRIPTION  :  This callback is called when the user chooses to open
+ *                 the help window.
+ * BEHAVIOR     :  Open the help window.
+ * PRE          :  /
+ */
+void help_cb (GtkWidget *,
+              gpointer);
 
 
 /* DESCRIPTION  :  This callback is called when the user choose to establish
@@ -96,9 +101,8 @@ about_callback (GtkWidget *,
  * BEHAVIOR     :  Call the remote endpoint or accept the incoming call.
  * PRE          :  /
  */
-void
-connect_cb (GtkWidget *,
-	    gpointer);
+void connect_cb (GtkWidget *,
+		 gpointer);
 
 
 /* DESCRIPTION  :  This callback is called when the user choose to stop
@@ -106,35 +110,40 @@ connect_cb (GtkWidget *,
  * BEHAVIOR     :  Do not accept the incoming call or stops the current call.
  * PRE          :  /
  */
-void
-disconnect_cb (GtkWidget *,
-	       gpointer);
-
-
-/* DESCRIPTION  :  This callback is called when the user chooses to open
- *                 or close some component.
- * BEHAVIOR     :  Shows or hide it.
- * PRE          :  gpointer is a valid pointer to the widget.
- */
-void
-gnomemeeting_component_view (GtkWidget *,
-			     gpointer);
+void disconnect_cb (GtkWidget *,
+		    gpointer);
 
 
 /* DESCRIPTION  :  This callback is called when the user chooses to quit.
  * BEHAVIOR     :  Quit.
  * PRE          :  /
  */
-void
-quit_callback (GtkWidget *,
-	       gpointer);
+void quit_callback (GtkWidget *,
+		    gpointer);
+
+
+/* DESCRIPTION  :  Simple wrapper that will call gnomemeeting_hide_window.
+ * BEHAVIOR     :  Calls gnomemeeting_window_hide.
+ * PRE          :  /
+ */
+gboolean delete_window_cb (GtkWidget *,
+                           GdkEvent *,
+                           gpointer);
+
+
+/* DESCRIPTION  :  Simple wrapper that will call gnomemeeting_show_window.
+ * BEHAVIOR     :  Calls gnomemeeting_window_show.
+ * PRE          :  The gpointer is a valid pointer to the GtkWindow that needs
+ *                 to be shown with the correct size and position.
+ */
+void show_window_cb (GtkWidget *,
+		     gpointer);
 
 
 /* DESCRIPTION  :  Quit callback.
- * BEHAVIOR     :  Quit  or not.
+ * BEHAVIOR     :  Disconnects, then simply call gtk_main_quit.
  * PRE          :  /
  */
-void
-gtk_main_quit_callback (int,
-			gpointer);
+void gtk_main_quit_callback (int,
+			     gpointer);
 #endif
