@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         common.h  -  description
  *                         ------------------------
  *   begin                : Sat Dec 23 2000
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : This file contains things common to the whole soft.
  *
  */
@@ -160,6 +160,8 @@ struct _GmTextChat
 {
   GtkWidget     *text_view;
   GtkTextBuffer *text_buffer;
+  gboolean	something_typed;
+  gchar		*begin_msg;
 };
 
 
@@ -201,8 +203,8 @@ struct _GmWindow
   GtkWidget *remote_name;
   GtkWidget *splash_win;
   GtkWidget *combo;
-  GtkWidget *history_window;
-  GtkWidget *history_text_view;
+  GtkWidget *log_window;
+  GtkWidget *log_text_view;
   GtkWidget *main_notebook;
   GtkWidget *main_video_image;
   GtkWidget *local_video_image;
@@ -296,6 +298,7 @@ struct _GmCallsHistoryWindow
   GtkListStore *given_calls_list_store;
   GtkListStore *received_calls_list_store;
   GtkListStore *missed_calls_list_store;
+  GtkWidget *search_entry;
 };
 
 
