@@ -113,8 +113,8 @@ GnomeMeeting::GnomeMeeting ()
 
   memset ((void *) rtp, 0, sizeof (struct _GmRtpData));
   gw->docklet = gw->ldap_window = gw->pref_window = gw->calls_history_window =
-    gw->splash_win = gw->incoming_call_popup = gw->log_window =
-    gw->audio_transmission_popup = gw->audio_reception_popup =
+    gw->splash_win = gw->incoming_call_popup = gw->transfer_call_popup =
+    gw->log_window = gw->audio_transmission_popup = gw->audio_reception_popup =
 #ifndef DISABLE_GNOME
     gw->druid_window =
 #endif
